/*
 * Decompiled with CFR 0.152.
 */
package com.jiuqi.util.chinese;

import com.jiuqi.util.chinese.ChineseDigitUnit;
import com.jiuqi.util.chinese.ChineseInt;
import com.jiuqi.util.chinese.NoValidCharException;
import com.jiuqi.util.chinese.NotValidChineseNumberException;
import com.jiuqi.util.chinese.StringSplitor;
import java.io.Serializable;

public class ChineseDouble
implements Cloneable,
Serializable {
    private static final char[] INVALID_CHARS = new char[]{' ', '\u3000'};
    private String dbValue;

    public ChineseDouble() {
        this.dbValue = "0";
    }

    public ChineseDouble(double value) {
        this.dbValue = String.valueOf(value);
    }

    public ChineseDouble(String value) {
        if (ChineseDouble.isDoubleString(value)) {
            this.dbValue = value;
        } else {
            try {
                this.dbValue = ChineseDouble.valueOf(value);
            }
            catch (Exception exception) {
                this.dbValue = "0";
            }
        }
    }

    public double doubleValue() {
        return Double.parseDouble(this.dbValue);
    }

    public String chineseValue(int frcLength, boolean showUnit, boolean useBigChar) {
        return ChineseDouble.parseToChinese(this.dbValue, frcLength, showUnit, useBigChar);
    }

    /*
     * Enabled force condition propagation
     * Lifted jumps to return sites
     */
    public static String valueOf(String chineseNumber) throws NotValidChineseNumberException, NoValidCharException {
        boolean isNegtive = false;
        boolean isPercent = false;
        boolean isPermillage = false;
        StringSplitor chars = new StringSplitor(chineseNumber, INVALID_CHARS);
        char thisChar = chars.getNextValidChar();
        if (thisChar == '(' || thisChar == '\uff08') {
            thisChar = chars.getNextValidChar();
            if (thisChar != '\u8d1f') throw new NotValidChineseNumberException("字符'('后面的字符无效，必须是'负'这个字符！");
            thisChar = chars.getNextValidChar();
            if (thisChar != ')' && thisChar != '\uff09') throw new NotValidChineseNumberException("字符'负'后面的字符无效，必须是')'这个字符！");
            isNegtive = true;
        }
        if (!isNegtive) {
            chars.rollBack();
        }
        if ((thisChar = chars.getNextValidChar()) == '\u767e' || thisChar == '\u4f70') {
            thisChar = chars.getNextValidChar();
            if (thisChar != '\u5206') throw new NotValidChineseNumberException("字符'百'('佰')后面的字符无效，必须是'分'这个字符！");
            thisChar = chars.getNextValidChar();
            if (thisChar != '\u4e4b') throw new NotValidChineseNumberException("字符'分'后面的字符无效，必须是'之'这个字符！");
            isPercent = true;
        } else if (thisChar == '\u5343' || thisChar == '\u4edf') {
            thisChar = chars.getNextValidChar();
            if (thisChar != '\u5206') throw new NotValidChineseNumberException("字符'千'('仟')后面的字符无效，必须是'分'这个字符！");
            thisChar = chars.getNextValidChar();
            if (thisChar != '\u4e4b') throw new NotValidChineseNumberException("字符'分'后面的字符无效，必须是'之'这个字符！");
            isPermillage = true;
        }
        if (!isPercent && !isPermillage) {
            chars.rollBack();
        }
        StringBuffer result = new StringBuffer();
        String left = chars.getLeft();
        int position = left.indexOf(28857);
        if (position != -1) {
            String intPart = left.substring(0, position);
            String frcPart = left.substring(position + 1);
            if (intPart.equals("")) {
                result.append("0");
            } else {
                result.append(ChineseInt.valueOf(intPart));
            }
            result.append(".");
            result.append(ChineseInt.valueOf(frcPart));
        } else {
            result.append(ChineseInt.valueOf(left));
        }
        if (isPercent) {
            result = new StringBuffer(ChineseDouble.leftMoveDot(result.toString(), 2));
        }
        if (isPermillage) {
            result = new StringBuffer(ChineseDouble.leftMoveDot(result.toString(), 3));
        }
        if (!isNegtive) return result.toString();
        result.insert(0, "-");
        return result.toString();
    }

    private static String leftMoveDot(String value, int count) {
        StringBuffer number = new StringBuffer(value);
        int position = number.indexOf(".");
        if (position == -1) {
            number.append(".");
            position = number.length() - 1;
        }
        if (count >= position) {
            int loopCount = count + 1 - position;
            int i = 0;
            while (i < loopCount) {
                number.insert(0, "0");
                ++position;
                ++i;
            }
        }
        number.deleteCharAt(position);
        number.insert(position - count, ".");
        ChineseDouble.removeExtraZero(number);
        return number.toString();
    }

    public static String parseToChinese(String value, int frcLength, boolean showUnit, boolean useBigChar) {
        if (ChineseDouble.isDoubleString(value)) {
            boolean isNegtive = false;
            if (value.startsWith("-")) {
                isNegtive = true;
                value = value.substring(1);
            }
            StringBuffer result = new StringBuffer();
            int dotPos = value.indexOf(46);
            String intPart = null;
            String frcPart = null;
            if (dotPos != -1) {
                intPart = value.substring(0, dotPos);
                frcPart = value.substring(dotPos + 1);
            } else {
                intPart = value;
                frcPart = "";
            }
            if (frcLength >= 0) {
                frcPart = ChineseDouble.getFrcPart(frcPart, frcLength);
            }
            result.append(ChineseInt.parseToChinese(intPart, showUnit, useBigChar));
            if (!frcPart.equals("")) {
                result.append("点");
                result.append(ChineseInt.parseToChinese(frcPart, false, useBigChar));
            }
            if (isNegtive) {
                result.insert(0, "（负）");
            }
            return result.toString();
        }
        throw new IllegalArgumentException("字符串\"" + value + "\"不是一个阿拉伯数字字符串！");
    }

    private static String getFrcPart(String frcPart, int frcLength) {
        int length = frcPart.length();
        if (length >= frcLength) {
            return frcPart.substring(0, frcLength);
        }
        StringBuffer sb = new StringBuffer(frcPart);
        int i = 0;
        while (i < frcLength - length) {
            sb.append("0");
            ++i;
        }
        return sb.toString();
    }

    public String getPercentForm(int frcLength, boolean showUnit, boolean useBigChar) {
        String value = this.dbValue;
        boolean negative = value.startsWith("-");
        if (negative) {
            value = value.substring(1);
        }
        String result = String.valueOf(ChineseDigitUnit.toChineseUnit("100", useBigChar)) + "分之" + ChineseDouble.parseToChinese(ChineseDouble.rightMoveDot(value, 2), frcLength, showUnit, useBigChar);
        if (negative) {
            result = "（负）" + result;
        }
        return result;
    }

    public String getPermillageForm(int frcLength, boolean showUnit, boolean useBigChar) {
        String value = this.dbValue;
        boolean negative = value.startsWith("-");
        if (negative) {
            value = value.substring(1);
        }
        String result = String.valueOf(ChineseDigitUnit.toChineseUnit("1000", useBigChar)) + "分之" + ChineseDouble.parseToChinese(ChineseDouble.rightMoveDot(value, 3), frcLength, showUnit, useBigChar);
        if (negative) {
            result = "（负）" + result;
        }
        return result;
    }

    private static String rightMoveDot(String value, int count) {
        StringBuffer number = new StringBuffer(value);
        int position = number.indexOf(".");
        if (position == -1) {
            number.append(".");
            position = number.length() - 1;
        }
        if (position + count > number.length() - 1) {
            int loopCount = position + count + 1 - number.length();
            int i = 0;
            while (i < loopCount) {
                number.append("0");
                ++i;
            }
        }
        number.deleteCharAt(position);
        number.insert(position + count, ".");
        ChineseDouble.removeExtraZero(number);
        return number.toString();
    }

    private static void removeExtraZero(StringBuffer number) {
        char c;
        int dotPos = number.indexOf(".");
        int i = 0;
        while (i < dotPos - 1) {
            c = number.charAt(0);
            if (c != '0') break;
            number.deleteCharAt(0);
            ++i;
        }
        dotPos = number.indexOf(".");
        i = number.length() - 1;
        while (i >= dotPos) {
            c = number.charAt(i);
            if (c != '0' && c != '.') break;
            number.deleteCharAt(number.length() - 1);
            --i;
        }
    }

    static boolean isDoubleString(String value) {
        int dotPos = value.indexOf(46);
        if (dotPos != -1) {
            String part1 = value.substring(0, dotPos);
            String part2 = value.substring(dotPos + 1);
            return ChineseInt.isIntString(part1) && ChineseInt.isIntString(part2);
        }
        return ChineseInt.isIntString(value);
    }

    public Object clone() {
        return new ChineseDouble(this.dbValue);
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof ChineseDouble)) {
            return false;
        }
        ChineseDouble value = (ChineseDouble)o;
        return this.dbValue.equals(value.dbValue);
    }

    public int hashCode() {
        int result = super.hashCode();
        if (this.dbValue != null) {
            result ^= this.dbValue.hashCode();
        }
        return result;
    }

    public String toString() {
        return this.chineseValue(-1, true, false);
    }
}

